==> haskell-case-insensitive-1.2.1.0-216-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
key:                  case-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  0600cf3bce00a9f7cec222b5abb9659b
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-case-insensitive
hs-libraries:         HScase-insensitive-1.2.1.0-KEn2hkRTWhZ23pGG8K2iDV
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    hashable-1.4.4.0-7BSyPsBurXt9vEzyIgxmkb text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-case-insensitive-1.2.1.0-218-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-case-insensitive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 case-insensitive
version:              1.2.1.0
visibility:           public
id:                   case-insensitive-1.2.1.0-70bos50a2k8AE0jNL30hL3
key:                  case-insensitive-1.2.1.0-70bos50a2k8AE0jNL30hL3
license:              BSD-3-Clause
copyright:            2011 Bas van Dijk
maintainer:           Bas van Dijk <v.dijk.bas@gmail.com>
author:               Bas van Dijk
homepage:             https://github.com/basvandijk/case-insensitive
synopsis:             Case insensitive string comparison
description:
    The module @Data.CaseInsensitive@ provides the '\''CI'\'' type
    constructor which can be parameterised by a string-like
    type like: '\''String'\'', '\''ByteString'\'', '\''Text'\'',
    etc.. Comparisons of values of the resulting type will be
    insensitive to cases.

category:             Data, Text
abi:                  be1712f23f922eef46f3122344c52eb4
exposed:              True
exposed-modules:      Data.CaseInsensitive Data.CaseInsensitive.Unsafe
hidden-modules:       Data.CaseInsensitive.Internal
import-dirs:          /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
library-dirs:         /usr/lib/ghc-9.2.8/site-local/case-insensitive-1.2.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-case-insensitive
hs-libraries:         HScase-insensitive-1.2.1.0-70bos50a2k8AE0jNL30hL3
depends:
    base-4.16.4.0 bytestring-0.11.4.0 deepseq-1.4.6.1
    hashable-1.4.4.0-Eh4n1fgdym83z63BlyWtti text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-case-insensitive/html/case-insensitive.haddock

haddock-html:         /usr/share/doc/haskell-case-insensitive/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
